@@ -486,6 +486,7 @@ RedshiftConnectorProfileCredentialsTypeDef = TypedDict(
         "username": str,
         "password": str,
     },
+    total=False,
 )
 
 ServiceNowConnectorProfileCredentialsTypeDef = TypedDict(
@@ -557,7 +558,6 @@ MarketoConnectorProfilePropertiesTypeDef = TypedDict(
 _RequiredRedshiftConnectorProfilePropertiesTypeDef = TypedDict(
     "_RequiredRedshiftConnectorProfilePropertiesTypeDef",
     {
-        "databaseUrl": str,
         "bucketName": str,
         "roleArn": str,
     },
@@ -565,7 +565,13 @@ _RequiredRedshiftConnectorProfilePropertiesTypeDef = TypedDict(
 _OptionalRedshiftConnectorProfilePropertiesTypeDef = TypedDict(
     "_OptionalRedshiftConnectorProfilePropertiesTypeDef",
     {
+        "databaseUrl": str,
         "bucketPrefix": str,
+        "dataApiRoleArn": str,
+        "isRedshiftServerless": bool,
+        "clusterIdentifier": str,
+        "workgroupName": str,
+        "databaseName": str,
     },
     total=False,
 )
@@ -2333,13 +2339,26 @@ class SourceFlowConfigTypeDef(_RequiredSourceFlowConfigTypeDef, _OptionalSourceF
     pass
 
 
-ConnectorProfileConfigTypeDef = TypedDict(
-    "ConnectorProfileConfigTypeDef",
+_RequiredConnectorProfileConfigTypeDef = TypedDict(
+    "_RequiredConnectorProfileConfigTypeDef",
     {
         "connectorProfileProperties": ConnectorProfilePropertiesTypeDef,
-        "connectorProfileCredentials": ConnectorProfileCredentialsTypeDef,
     },
 )
+_OptionalConnectorProfileConfigTypeDef = TypedDict(
+    "_OptionalConnectorProfileConfigTypeDef",
+    {
+        "connectorProfileCredentials": ConnectorProfileCredentialsTypeDef,
+    },
+    total=False,
+)
+
+
+class ConnectorProfileConfigTypeDef(
+    _RequiredConnectorProfileConfigTypeDef, _OptionalConnectorProfileConfigTypeDef
+):
+    pass
+
 
 DescribeConnectorEntityResponseTypeDef = TypedDict(
     "DescribeConnectorEntityResponseTypeDef",
